@@ -75,24 +75,14 @@ def related_vaild_legal_decorator(func):
 
 def tenant_decorator(func):
     def wrapper(obj_view, request, *args, **kwargs):
-        tenant = None
-        req_args = dict(request.GET.dict())
-        token = req_args.pop('token', None)
+        tenant = request._request.tenant
+        req_args = request.GET.dict()
         if request.method == 'GET':
-            data = req_args
-            ignore_creator = data.pop('ignore_creator', "False").lower() == 'true'
+            ignore_creator = req_args.pop('ignore_creator', "False").lower() == 'true'
             if ignore_creator:
                 return func(obj_view, request, *args, **kwargs)
         else:
             data = request.data
-
-        if token:
-            tenant = Tenant.objects.filter(token=token).first()
-        else:
-            account = request.session.get('account')
-            if account:
-                tenant = Tenant.objects.filter(account=account).first()
-        if tenant:
             if isinstance(data, dict):
                 if 'data' in data.keys() and 'ops' in data.keys():
                     data = data.get('data', {})
@@ -109,10 +99,49 @@ def tenant_decorator(func):
                 else:
                     kwargs["extend_conditions"] = {"creator": tenant.name}
             return func(obj_view, request, *args, **kwargs)
-        else:
-            results = Results()
-            results.code = FORBID_CODE
-            results.describe = "无登陆信息!!!"
-            return RESTResponse(results)
 
     return wrapper
+
+# def tenant_decorator(func):
+#     def wrapper(obj_view, request, *args, **kwargs):
+#         tenant = None
+#         req_args = dict(request.GET.dict())
+#         token = req_args.pop('token', None)
+#         if request.method == 'GET':
+#             data = req_args
+#             ignore_creator = data.pop('ignore_creator', "False").lower() == 'true'
+#             if ignore_creator:
+#                 return func(obj_view, request, *args, **kwargs)
+#         else:
+#             data = request.data
+#
+#         if token:
+#             tenant = Tenant.objects.filter(token=token).first()
+#         else:
+#             account = request.session.get('account')
+#             if account:
+#                 tenant = Tenant.objects.filter(account=account).first()
+#         if tenant:
+#             if isinstance(data, dict):
+#                 if 'data' in data.keys() and 'ops' in data.keys():
+#                     data = data.get('data', {})
+#             if request.method == 'POST' or request.method == 'PUT':
+#                 if isinstance(data, list):
+#                     for item in data:
+#                         item['creator'] = tenant.name
+#                 else:
+#                     data['creator'] = tenant.name
+#                 kwargs["data"] = data
+#             if request.method == 'GET':
+#                 if "extend_conditions" in kwargs.keys():
+#                     kwargs["extend_conditions"]['creator'] = tenant.name
+#                 else:
+#                     kwargs["extend_conditions"] = {"creator": tenant.name}
+#             return func(obj_view, request, *args, **kwargs)
+#         else:
+#             results = Results()
+#             results.code = FORBID_CODE
+#             results.describe = "无登陆信息!!!"
+#             return RESTResponse(results)
+#
+#     return wrapper
