@@ -3,8 +3,10 @@ import uuid
 from datetime import datetime
 
 
-def dt_time():
-    nnn = time.time() - 8 * 60 * 60
+
+def dt_time(sub=8):
+    sub = int(sub)
+    nnn = time.time() - sub * 60 * 60
     dat = datetime.fromtimestamp(nnn)
     ttt = dat.strftime("%Y-%m-%dT%H:%M:%S.%fZ")
     return ttt
